#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitrev
version:              1.3.1
visibility:           public
id:                   gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
key:                  gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
license:              BSD-3-Clause
maintainer:           acfoltzer@galois.com
author:               Adam C. Foltzer
homepage:             https://github.com/acfoltzer/gitrev
synopsis:             Compile git revision info into Haskell projects
description:
    Some handy Template Haskell splices for including the current git hash and branch in the code of your project. Useful for including in panic messages, @--version@ output, or diagnostic info for more informative bug reports.

category:             Development
abi:                  5255e0a02e80888e8d8693a958edefa3
exposed:              True
exposed-modules:      Development.GitRev
import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitrev-1.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitrev-1.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitrev-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gitrev
hs-libraries:         HSgitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    directory-1.3.8.5 filepath-1.4.300.1 process-1.6.19.0
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-gitrev/html/gitrev.haddock
haddock-html:         /usr/share/doc/haskell-gitrev/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

